@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -21,7 +21,7 @@ class ErrorWorker : public AsyncWorker {
 };
 
 NAN_METHOD(Work) {
-  Callback *callback = new Callback(info[0].As<v8::Function>());
+  Callback *callback = new Callback(To<v8::Function>(info[0]).ToLocalChecked());
   AsyncQueueWorker(new ErrorWorker(callback));
   info.GetReturnValue().SetUndefined();
 }
@@ -29,7 +29,7 @@ NAN_METHOD(Work) {
 NAN_MODULE_INIT(Init) {
   Set(target
     , New("a").ToLocalChecked()
-    , New<v8::FunctionTemplate>(Work)->GetFunction());
+    , GetFunction(New<v8::FunctionTemplate>(Work)).ToLocalChecked());
 }
 
 NODE_MODULE(asyncworkererror, Init)
