@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -36,6 +36,7 @@ class TlsTest : public AsyncWorker {
       t->ok(res[j].ok, res[j].msg);
     nauv_key_delete(&tls_key);
     t->ok(_(NULL == ErrorMessage()));
+    t->end();
     delete t;
   }
 
@@ -62,7 +63,8 @@ NAN_METHOD(thread_local_storage) {
 NAN_MODULE_INIT(Init) {
   Set(target
     , New<v8::String>("thread_local_storage").ToLocalChecked()
-    , New<v8::FunctionTemplate>(thread_local_storage)->GetFunction()
+    , GetFunction(New<v8::FunctionTemplate>(thread_local_storage))
+        .ToLocalChecked()
   );
 }
 
